module IRC
  module Handlers
    class ConnectionHandler < Event::Handler
      def on_connection_established
        puts "*** Connection established"
      end

      def on_disconnected
        puts "*** Disconnected"
      end

      def on_005 # RPL_ISUPPORT
        response.args[1..-1].each do |support_info|
          feature, value = support_info.split("=", 2)
          fire(:server_supports, :feature => feature, :value => value)
        end
      end

      def on_ping
        request(:pong, :text => response.text)
      end

      def on_privmsg
        if response.text[/^\001(.*?)( (.*))?\001$/]
          stop if fire("ctcp_#{$1.downcase}", :text => $3)
        end
      end
      
      def on_ctcp_version
        ctcp_reply(response.from.nickname, :version, "Ruby IRC")
      end
      
      def on_ctcp_ping
        ctcp_reply(response.from.nickname, :ping, memo[:text])
      end
      
      def on_ctcp_time
        ctcp_reply(response.from.nickname, :time, Time.now.strftime("%Y-%m-%d %H:%M:%S %z"))
      end

      def ctcp_request(target, type, text = nil)
        request(:privmsg, target, :text => ctcp_text(type, text))
      end
      
      def ctcp_reply(target, type, text = nil)
        request(:notice, target, :text => ctcp_text(type, text))
      end
      
      protected
        def ctcp_text(type, text)
          "\001#{type.to_s.upcase}#{" #{text}" if text}\001"
        end
    end
  end
end
